'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
var taggedLiteral = function taggedLiteral() {
  for (var _len = arguments.length, values = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    values[_key - 1] = arguments[_key];
  }

  var literals = arguments.length <= 0 || arguments[0] === undefined ? [] : arguments[0];

  return literals.reduce(function (result, literal, index) {
    result += literal;
    if (index < values.length) result += values[index];
    return result;
  }, '');
};

var initialWhitespace = function initialWhitespace() {
  var str = arguments.length <= 0 || arguments[0] === undefined ? '' : arguments[0];

  var stripped = str.replace(newlines, '').replace(emptyLines, '\n');
  var count = 0;

  for (var i = 0, m = stripped.length; i < m; i++) {
    if (stripped[i] === ' ') {
      count++;
    } else {
      return count;
    }
  }

  return count;
};

var newlines = /\n/g;
var emptyLines = /\n\s*\n/g;
var whitespaceAfterNewlines = /\n\s*/g;
var trailingNewline = /\n$/;
var stripNewlineWhitespace = function stripNewlineWhitespace(str) {
  return new RegExp('\\n\\s{' + initialWhitespace(str) + '}', 'g');
};
var stripFirstNewlineWhitespace = function stripFirstNewlineWhitespace(str) {
  return new RegExp('^\\n\\s{' + initialWhitespace(str) + '}');
};

var minify = exports.minify = function minify() {
  return taggedLiteral.apply(undefined, arguments)
  // Strip all newlines followed by any number of spaces
  .replace(whitespaceAfterNewlines, '');
};

var unindent = exports.unindent = function unindent() {
  for (var _len2 = arguments.length, args = Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
    args[_key2 - 1] = arguments[_key2];
  }

  var literals = arguments.length <= 0 || arguments[0] === undefined ? [] : arguments[0];
  return taggedLiteral.apply(undefined, [literals].concat(args))
  // Strip leading newline + initial whitespace
  .replace(stripFirstNewlineWhitespace(literals[0]), '')
  // Replace all other newlines + initial whitespace with newlines
  .replace(stripNewlineWhitespace(literals[0]), '\n')
  // Replace empty blank lines with newlines
  .replace(emptyLines, '\n')
  // Strip trailing newline
  .replace(trailingNewline, '');
};